weaviate.contextionary package
==============================

.. automodule:: weaviate.contextionary
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.contextionary.crud\_contextionary module
-------------------------------------------------

.. automodule:: weaviate.contextionary.crud_contextionary
   :members:
   :undoc-members:
   :show-inheritance:
